Importing transactions, entering orders into the QUIK ARQA Technologies trading system via the API.
This functionality is designed to send transactions, the functionality is implemented through the API in the form of a library Trans2QUIK.dll .
The library contains functions, when calling these functions, you can:
- Establish or break the connection between the QUIK Workplace and the library Trans2QUIK.dll
- Check if there is a connection between the QUIK Workplace and the library Trans2QUIK.dll and between the QUIK Workplace and the QUIK server.
- Send the transaction.
- Get information on applications and transactions.
There are two ways to transfer transactions – synchronous and asynchronous, which are implemented by separate functions:
- With synchronous transaction transfer, the function is exited only after receiving a response from the QUIK server. Therefore, synchronous transactions can only be sent sequentially, waiting for a response about each sent transaction – this method is simpler and more suitable for programmers with little software development experience.
- With asynchronous transaction transfer, the function is exited immediately. The callback function is used to receive a response about sent asynchronous transactions. The function is called every time a response is received about an executed or rejected transaction.
A callback function is also provided to monitor connections between the QUIK terminal and the library Trans2QUIK.dll and between the QUIK Workplace and the QUIK server.
To receive information about orders and transactions, the user must first create a list of received instruments, separately for applications and transactions. Then the procedure for obtaining information using the callback functions is started. Upon termination of receiving information on applications and transactions, the lists of received instruments are cleared.
Structs
- ORDER_
STATUS_ SENDER - Order
Info - TRADE_
STATUS_ SENDER - TRANSACTION_
REPLY_ SENDER - Terminal
- The
Terminalstructure is used to interact with the QUIK trading terminal through the library Trans2QUIK.dll. - Trade
Info - Transaction
Info
Enums
- IsSell
- Sending an application.
- Mode
- Represents the state of order receipt.
- Status
- Represents the execution status of an order.
- Trans2
Quik Error - Сomposite error type for calling functions from the library Trans2QUIK.dll.
- Trans2
Quik Result - Corresponds to the description of constants whose values are returned when exiting functions and procedures in the library Trans2QUIK.dll:
- TransId
- The TransID of the transaction that generated the request.
It has a value of
0if the request was not generated by a transaction from a file, or if the TransID is unknown.